@@ -78,6 +78,8 @@ public:
   void setSoundSourceFormat(const CSourceFormat& format);
   //! \brief  Хåեꤹ롣
   void setBufferSize(int nSize);
+  //! \brief  ֤֤߰
+  QTime pos();
 
 public slots:
   //! \brief 󥻥åȥåפ򿷵롣
@@ -166,6 +168,8 @@ private:
   QValueVector<CTrackInf> vPrepareTrackChains;
   //! IDEcasoundλ(Finished)Ƚ˻ѡ
   int nTimerIDFinished;
+  //! IDּ߰˻ѡ
+  int nTimerIDCurrentPos;
   //! ޥݥ(ϰ())
   int nMasterPosition;
   //! ե̾Υꥹȡ
@@ -193,6 +197,7 @@ private:
   void setMixdownIOToCurrentChainsetup(bool bWithPlaying, const QString& strFileName);
   //! \brief ޥ٥ȡ
   //! Ecasoundκλ(Finished)Ƚꤹ뤿Υޥ٥ȡ
+  //! EcasoundΥץ֤Ƚꤹ뤿Υޥ٥ȡ
   void timerEvent(QTimerEvent* TimerEvent);
   //! \brief .ewfե롣
   //! \param strTrackName ȥå̾Ρ
@@ -236,6 +241,8 @@ signals:
   //! \brief Ecasoundξ֤Finishedˤʤäȯ륷ʥ롣
   //! Stopped֤ˤʤäƤȯʤ
   void finished();
+  //! \brief ˸֤߰Τ餻뤿ȯ륷ʥ롣
+  void moved(const QTime&);
 };
 
 #endif
