@@ -66,7 +66,7 @@ CEwf::valueType(const QString& strLine)
   strTmp.replace(QChar(' '), "");
 
   // is empty
-  if ( (strLine == "") || (strLine == " ") ) {
+  if ( (strLine.isEmpty()) || (strLine == " ") ) {
     return Comment;
   }
 
@@ -304,9 +304,9 @@ void
 CEwf::set(const CTrackInf& TrackInf)
 {
   strFileName       = TrackInf.strFileName;
-  timeOffset        = TrackInf.TimeOffset;
-  timeStartPosition = TrackInf.TimeStartPosition;
-  timeLength        = TrackInf.TimeLength;
+  timeOffset        = TrackInf.timeOffset;
+  timeStartPosition = TrackInf.timeStartPosition;
+  timeLength        = TrackInf.timeLength;
   bLooping          = false;
 }
 
@@ -350,7 +350,7 @@ CEwf::writeEcasoundWaveFile(const QString& strEwf)
 
   // source
   // if source file name is empty, return false
-  if ( strFileName == "" ) {
+  if ( strFileName.isEmpty() ) {
     return false;
   }
   out << "source = ";
