@@ -20,6 +20,7 @@
 
 #include <qstring.h>
 #include <qstringlist.h>
+#include <qwidget.h>
 
 /*-------------------------------------------------------------------------*/
 /*! \class CVoxStormGlobal
@@ -95,6 +96,21 @@ public:
   //! \param  strTrackName ȥå̾Ρ
   static bool isValidTrackName(const QString& strTrackName);
 
+  //! \brief  ѡߥåUNIX"ls -l"ޥɤνϥեޥåȤ֤
+  //! \param  ե̾Ρ
+  static QString permissionInUNIXFormat(const QString& strFileName);
+
+  //! \brief  ۡǥ쥯ȥХѥǼ롣
+  static QString homeDir();
+
+  //! \brief  ƬΥХѥ(ۡǥ쥯ȥ)Ѵ롣
+  static QString absPath(const QString& strPath);
+
+  //! \brief  ǥ쥯ȥ뤫ɤǧ׵᤬к롣
+  //! \return ǥ쥯ȥκ뤫¸ߤtrue֤
+  //!         ׵᤬ݤ뤫˼Ԥfalse֤
+  static bool queryAndCreateDir(QWidget* WidgetParent, const QString& strDirName);
+
 private:
   //! \brief 󥹥󥹲ػߤ뤿Υߡؿ
   virtual void dummy() = 0;
