@@ -43,7 +43,6 @@
 WVoxBase::WVoxBase(QWidget *WidgetParent, const char *cName)
   : QVBox(WidgetParent, cName)
 {
-  nTimerIDProceed = 0;
   setupWidgets();
 }
 
@@ -55,7 +54,6 @@ WVoxBase::WVoxBase(
       const char*     cName)
   : QVBox(WidgetParent, cName)
 {
-  nTimerIDProceed = 0;
   setupWidgets();
   addTracks(nodBase);
 }
@@ -64,8 +62,6 @@ WVoxBase::WVoxBase(
 
 WVoxBase::~WVoxBase()
 {
-  killTimers();  // kill all timers
-
   if (vVoxTracks.empty() ) {
     return;
   }
@@ -125,7 +121,7 @@ WVoxBase::addTrack(
                                   strDeviceIn,
                                   strDeviceOut,
                                   timeMaxSessionLength, 
-                                  VBoxTracks);
+                                  FrameTracks);
 
   SignalMapperPlayback->setMapping(VoxTrackNew, strTrackName);
   connect(VoxTrackNew, SIGNAL(playbackDeviceChanged(const QString&)),
@@ -175,6 +171,7 @@ WVoxBase::addTrack(
   connect(VoxTrackNew, SIGNAL(stateChanged()), 
           this, SIGNAL(stateChanged()));
 
+  VLayoutTracks->addWidget(VoxTrackNew);
   vVoxTracks.push_back(VoxTrackNew);
   VoxTrackNew->show();
 }
@@ -195,7 +192,7 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
     WVoxTrack *VoxTrackNew = new WVoxTrack(
                                    nolTracks.item(i), 
                                    timeMaxSessionLength, 
-                                   VBoxTracks);
+                                   FrameTracks);
     QString strTrackName = VoxTrackNew->name();
 
     SignalMapperPlayback->setMapping(VoxTrackNew, strTrackName);
@@ -248,6 +245,7 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
 
     VoxTrackNew->setMaxSessionLength(timeMaxSessionLength);
 
+    VLayoutTracks->addWidget(VoxTrackNew);
     vVoxTracks.push_back(VoxTrackNew);
     VoxTrackNew->show();
   }
@@ -321,6 +319,8 @@ WVoxBase::removeTrack(const QString& strTrackName)
       SignalMapperStartPosition->removeMappings(vVoxTracks[i]);
       SignalMapperOffset->removeMappings(vVoxTracks[i]);
       SignalMapperLength->removeMappings(vVoxTracks[i]);
+
+      VLayoutTracks->remove(vVoxTracks[i]);
       delete vVoxTracks[i];
     } else {
       vVoxTracksTmp.push_back(vVoxTracks[i]);
@@ -447,9 +447,10 @@ WVoxBase::setupWidgets()
   ScrollView->setHScrollBarMode(QScrollView::AlwaysOff);
   ScrollView->setVScrollBarMode(QScrollView::AlwaysOn);
 
-  VBoxTracks = new QVBox(Splitter);
-  VBoxTracks->setMinimumHeight(300);
-  ScrollView->addChild(VBoxTracks);
+  FrameTracks = new QFrame(Splitter);
+  FrameTracks->setMinimumHeight(300);
+  VLayoutTracks = new QVBoxLayout(FrameTracks);
+  ScrollView->addChild(FrameTracks);
 
   // >>>> setup bottom tab
   Tab = new QTabWidget(Splitter);
@@ -551,7 +552,7 @@ void
 WVoxBase::resizeEvent(QResizeEvent* Event)
 {
   QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
-  VBoxTracks->resize(Event->size().width() - 24, VBoxTracks->height());
+  FrameTracks->resize(Event->size().width() - 24, FrameTracks->height());
   while ( it != vVoxTracks.end() ) {
     (*it)->resize(Event->size().width() - 24, (*it)->height());
     it++;
@@ -562,20 +563,6 @@ WVoxBase::resizeEvent(QResizeEvent* Event)
 
 /////////////////////////////////////////////////////////////////////////////
 
-void 
-WVoxBase::timerEvent(QTimerEvent* Event)
-{
-  if ( Event->timerId() == nTimerIDProceed ) {  // playing
-    timeProceed = timeProceed.addSecs(1);
-    TimeEditProceed->setTime(timeProceed);
-  } else if ( Event->timerId() == nTimerIDPausing ) {  // pausing
-  }
-
-  QVBox::timerEvent(Event);
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 void
 WVoxBase::slotWriteConsoleMessage(const QString& strMessage)
 {
@@ -615,17 +602,10 @@ WVoxBase::slotChangeState(State state)
                false);
       it++;
     }
-    if ( nTimerIDProceed == 0 && nTimerIDPausing != 0 ) {  // in pausing
-      nTimerIDProceed = nTimerIDPausing;
-      nTimerIDPausing = 0;
-    } else {
-      timeProceed = QTime();
-      TimeEditProceed->setTime(timeProceed);
-      TimeEditProceed->show();
-      LabelProceed->show();
-      nTimerIDProceed = startTimer(1000); // 1 second timer
-      nTimerIDPausing = 0;
-    }
+    timeProceed = QTime();
+    TimeEditProceed->setTime(QTime());
+    TimeEditProceed->show();
+    LabelProceed->show();
   }
   // PAUSE
   else if ( state == Pause ) {
@@ -644,17 +624,11 @@ WVoxBase::slotChangeState(State state)
                false);
       it++;
     }
-    nTimerIDPausing = nTimerIDProceed;
-    nTimerIDProceed = 0;
   }
   // STOP
   else if ( state == Stop ) {
     TimeEditProceed->hide();
     LabelProceed->hide();
-    killTimer(nTimerIDProceed);
-    nTimerIDProceed = 0;
-    nTimerIDPausing = 0;
-    timeProceed = TimeEditPosition->time();
     while ( it != vVoxTracks.end() ) {
       (*it)->slotSetEnabledWidgets(
                WVoxTrack::Record |
@@ -690,6 +664,42 @@ WVoxBase::slotNotifySucceedInRecording()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxBase::slotNotifyCurrentTime(const QTime& time)
+{
+  if ( TimeEditProceed->isShown() ) {
+    TimeEditProceed->setTime(time);
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+WVoxBase::slotChangeTrackOrder(QValueVector<int> vOrder)
+{
+  if ( vOrder.size() != vVoxTracks.size() ) {
+    return;
+  }
+
+  // removed all widget from layout
+  {
+    QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
+    while ( it != vVoxTracks.end() ) {
+      VLayoutTracks->remove(*it);
+      it++;
+    }
+  }
+
+  // relayout
+  int i;
+  int nCount = vVoxTracks.size();
+  for ( i = 0; i < nCount; i++ ) {
+    VLayoutTracks->addWidget(vVoxTracks[vOrder[i]]);
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 WVoxBase::slotAddTrack()
 {
