@@ -20,6 +20,7 @@
 
 #include <qsignalmapper.h>
 #include <qvbox.h>
+#include <qlayout.h>
 #include <qvaluevector.h>
 #include <qdatetimeedit.h>
 #include <qtabwidget.h>
@@ -131,7 +132,6 @@ public:
 
 protected:
   void resizeEvent(QResizeEvent* Event);
-  void timerEvent(QTimerEvent* Event);
 
 private:
   //! ϰ֤ɽ뤿Υåȡ
@@ -142,8 +142,10 @@ private:
   QTimeEdit     *TimeEditProceed;
   //! ȥåǼ٥
   QValueVector<WVoxTrack*> vVoxTracks;
-  //! ȥåɽΰ衣
-  QVBox         *VBoxTracks;
+  //! ȥå֤뤿Υ쥤ȡ
+  QVBoxLayout   *VLayoutTracks;
+  //! ȥåɽΤΥåȡ
+  QFrame        *FrameTracks;
   //! ̤ɽΰ衣
   QTabWidget    *Tab;
   //! Ecasoundޥɥ饤ϤΤΥǥåȡ
@@ -178,10 +180,6 @@ private:
   //! åĹ
   QTime         timeMaxSessionLength;
 
-  //! ʹԻɽѥID
-  int           nTimerIDProceed;
-  //! ߻ХååѥID
-  int           nTimerIDPausing;
   //! ʹԻ֡
   QTime         timeProceed;
 
@@ -207,6 +205,10 @@ public slots:
   //! \brief  Ͽλ˸ƤӽФ٤åȡ
   //! ȥåΤϿꤵƤΤΥեåȡ֡Ĺ򥼥ˤ롣
   void slotNotifySucceedInRecording();
+  //! \brief  ʹԻ֤륹åȡ
+  void slotNotifyCurrentTime(const QTime& time);
+  //! \brief  ȥåѹ륹åȡ
+  void slotChangeTrackOrder(QValueVector<int> vOrder);
 
 private slots:
   //! \brief ȥåɲ׵Ф륹åȡ
