@@ -45,6 +45,7 @@
 #include "wvoxstorm.h"
 #include "wmixdowndialog.h"
 #include "cvoxstormglobal.h"
+#include "worderdialog.h"
 
 /////////////////////////////////////////////////////////////////////////////
 
@@ -131,6 +132,8 @@ WVoxStorm::initialize()
   connect(&ecaIAManager, SIGNAL(finished()), this, SLOT(slotFinish()));
   connect(&ecaIAManager, SIGNAL(messageGenerated(const QString&)),
           VoxBase, SLOT(slotWriteConsoleMessage(const QString&)));
+  connect(&ecaIAManager, SIGNAL(moved(const QTime&)), 
+          VoxBase, SLOT(slotNotifyCurrentTime(const QTime&)));
 
   pDocVox = NULL;
 
@@ -402,14 +405,14 @@ WVoxStorm::setupActions()
                        "Add Track");
   Action->plug(PopupMenu);
 
-  Action = new KAction(i18n("&Track Order"),
+  ActionTrackOrder = new KAction(i18n("&Track Order"),
                        NULL,
                        0,
                        this,
                        SLOT(slotTrackOrder()),
                        actionCollection(),
                        "Track Order");
-  Action->plug(PopupMenu);
+  ActionTrackOrder->plug(PopupMenu);
 
   menuBar()->insertItem(i18n("&Track"), PopupMenu);
 
@@ -809,6 +812,7 @@ WVoxStorm::slotPlay()
     if ( bPause ) {  // PAUSE -> PLAY
       ActionPlay->setEnabled(false);
       ToggleActionRec->setEnabled(false);
+      ActionTrackOrder->setEnabled(false);
       ActionMixdown->setEnabled(false);
       VoxBase->slotChangeState(WVoxBase::Play);
       VoxBase->slotChangeMessageTab(WVoxBase::Console);
@@ -824,6 +828,7 @@ WVoxStorm::slotPlay()
 
       ActionPlay->setEnabled(false);
       ToggleActionRec->setEnabled(false);
+      ActionTrackOrder->setEnabled(false);
       ActionMixdown->setEnabled(false);
       VoxBase->slotChangeState(WVoxBase::Play);
       VoxBase->slotChangeMessageTab(WVoxBase::Console);
@@ -941,6 +946,7 @@ WVoxStorm::slotMixdown()
   ActionJumpToStart->setEnabled(false);
   ActionRewind->setEnabled(false);
   ActionForward->setEnabled(false);
+  ActionTrackOrder->setEnabled(false);
   ActionMixdown->setEnabled(false);
   VoxBase->slotChangeState(WVoxBase::Play);
   VoxBase->slotChangeMessageTab(WVoxBase::Console);
@@ -1006,7 +1012,23 @@ WVoxStorm::slotAddTrack()
 void
 WVoxStorm::slotTrackOrder()
 {
-  ;
+  WOrderDialog dialog(this);
+
+  // set track names
+  {
+    QStringList strl;
+    int i;
+    int nCount = VoxBase->getTrackCount();
+    for ( i = 0; i < nCount; i++ ) {
+      strl.push_back(VoxBase->getTrackInf(i).strTrackName);
+    }
+    dialog.slotSetList(strl);
+  }
+
+  if ( dialog.exec() == QDialog::Accepted ) {
+    VoxBase->slotChangeTrackOrder(dialog.order());
+    slotChangedState();
+  }
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -1185,6 +1207,7 @@ WVoxStorm::slotFinish()
   }
   VoxBase->slotChangeState(WVoxBase::Stop);
   ActionMixdown->setEnabled(true);
+  ActionTrackOrder->setEnabled(true);
   ActionForward->setEnabled(true);
   ActionRewind->setEnabled(true);
   ActionJumpToStart->setEnabled(true);
